==> mysql-connector-java-6.0.2-sources.jar: com/mysql/cj/core/io/ShortValueFactory.java <==
/*
  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.core.io;

import java.math.BigDecimal;
import java.math.BigInteger;

/**
 * A value factory for creating short values.
 */
public class ShortValueFactory extends DefaultValueFactory<Short> {
    public Short createFromBigInteger(BigInteger i) {
        return (short) i.intValue();
    }

    public Short createFromLong(long l) {
        return (short) l;
    }

    public Short createFromBigDecimal(BigDecimal d) {
        return (short) d.longValue();
    }

    public Short createFromDouble(double d) {
        return (short) d;
    }

    public Short createFromNull() {
        return (short) 0;
    }

    public String getTargetTypeName() {
        return Short.class.getName();
    }
}

==> mysql-connector-java-6.0.4-sources.jar: com/mysql/cj/core/io/ShortValueFactory.java <==
/*
  Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.core.io;

import java.math.BigDecimal;
import java.math.BigInteger;

import com.mysql.cj.mysqla.MysqlaUtils;

/**
 * A value factory for creating short values.
 */
public class ShortValueFactory extends DefaultValueFactory<Short> {
    @Override
    public Short createFromBigInteger(BigInteger i) {
        return (short) i.intValue();
    }

    @Override
    public Short createFromLong(long l) {
        return (short) l;
    }

    @Override
    public Short createFromBigDecimal(BigDecimal d) {
        return (short) d.longValue();
    }

    @Override
    public Short createFromDouble(double d) {
        return (short) d;
    }

    @Override
    public Short createFromBit(byte[] bytes, int offset, int length) {
        return createFromLong(MysqlaUtils.bitToLong(bytes, offset, length));
    }

    @Override
    public Short createFromNull() {
        return (short) 0;
    }

    public String getTargetTypeName() {
        return Short.class.getName();
    }
}
